import request from "utils/request";
import download from "utils/download";

/***** 设备类型 *****/

//  设备类型--获取设备类型级别分页表格
export function getTableListOfDeviceType (object) {
    return request({
        url: '/device/deviceLevel/getDeviceLevelList',
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备类型--校验系统重名
export function checkSameSystemCodeOfDeviceType (object) {
    return request({
        url: '/device/patrolSystem/checkSysCodeAndName',
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备类型--提交新增、编辑系统表单
export function submitSystemFormOfDeviceType (object) {
    return request({
        url: '/device/patrolSystem/savePatrolSystem',
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备类型--提交删除系统表单
export function submitDeleteSystemFormOfDeviceType (object) {
    return request({
        url: `/device/patrolSystem/deleteSystem/${object.sysId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备类型--校验级别重名
export function checkSameLevelCodeOfDeviceType (object) {
    return request({
        url: '/device/deviceLevel/checkCode',
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备类型--提交新增级别表单
export function submitLevelAddFormOfDeviceType (object) {
    return request({
        url: '/device/deviceLevel/saveDeviceLevel',
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备类型--提交编辑级别表单
export function submitLevelEditFormOfDeviceType (object) {
    return request({
        url: '/device/deviceLevel/editDeviceLevel',
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备类型--提交删除级别表单
export function submitDeleteLevelFormOfDeviceType (object) {
    return request({
        url: `/device/deviceLevel/deleteById/${object.levelId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}

/***** 标准设置 *****/

//  标准设置--获取标准分页表格
export function getTableListOfStandard (object) {
    return request({
        url: `/device/deviceLevel/getDeviceLevelFields`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  标准设置--提交新增标准表单
export function submitAddFormOfStandard (object) {
    return request({
        url: `/device/qualityFormate/saveDeviceLevelField`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  标准设置--提交编辑标准表单
export function submitEditFormOfStandard (object) {
    return request({
        url: `/device/deviceLevelField/editDeviceLevelField`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  标准设置--获取标准详情
export function getDetailDataOfStandard (object) {
    return request({
        url: `/device/deviceLevelField/findById`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  标准设置--提交删除标准表单
export function submitDeleteFormOfStandard (object) {
    return request({
        url: `/device/deviceLevelField/deleteById/${object.fieldId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}

/***** 设备空间 *****/

//  设备空间--获取空间分页表格
export function getTableListOfSpace (object) {
    return request({
        url: `/device/jywsRoom/getAddressPage/${object.pageSize}/${object.pageIndex}`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备空间--下载二维码
export function downloadQrCodeOfSpace (object) {
    return download({
        url: `/device/address/getAddressQrCode${object.devicePartrolId ? '/' + object.devicePartrolId : ''}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备空间--生成二维码
export function createQrCodeOfSpace (object) {
    return request({
        url: `/device/address/rebulidAddressQrCode`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备空间--提交新增机房表单
export function submitAddFormOfSpace (object) {
    return request({
        url: `/device/address/saveAddress`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备空间--提交编辑机房表单
export function submitEditFormOfSpace (object) {
    return request({
        url: `/device/address/editAddress/${object.devicePartrolId}`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备空间--获取机房详情
export function getDetailDataOfSpace (object) {
    return request({
        url: `/device/address/byId/${object.devicePartrolId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}

/***** 工艺路线 *****/

//  工艺路线--获取工艺路线未分页表格
export function getProcessTableListOfRoute (object) {
    return request({
        url: `/device/deviceCraft/getDeviceCraftByCompanyId`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--提交新增、编辑工艺路线表单
export function submitProcessFormOfRoute (object) {
    return request({
        url: `/device/deviceCraft/saveDeviceCraft`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  工艺路线--提交删除工艺路线表单
export function submitDeleteProcessFormOfRoute (object) {
    return request({
        url: `/device/deviceCraft/deleteById`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--获取标准内容分页表格
export function getStandardTableListOfRoute (object) {
    return request({
        url: `/device/deviceCraft/getGuardTourFormByCraftId`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--获取标准内容分页表格步骤数据
export function getStandardStepTableListOfRoute (object) {
    return request({
        url: `/device/deviceCraft/getGuardTourFormField`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--获取工艺路线已关联类型数据
export function getStandardExistTypeListOfRoute (object) {
    return request({
        url: `/device/jywsRoomCraft/getGuardTourFormByCraftId`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--提交关联类型表单
export function submitTypeFormOfRoute (object) {
    return request({
        url: `/device/guardtourForm/editGuardtourForm`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  工艺路线--获取可用步骤未分页表格数据
export function getAvailableStepTableListOfRoute (object) {
    return request({
        url: `/device/deviceCraft/getFieldsByformId`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--提交新增步骤表单
export function submitStepFormOfRoute (object) {
    return request({
        url: `/device/guardtourFormField/addField`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  工艺路线--提交删除步骤表单
export function submitDeleteStepFormOfRoute (object) {
    return request({
        url: `/device/guardtourFormField/deleteField`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}

/***** 设备列表 *****/

//  设备列表--获取分页表格
export function getTableListOfDeviceList (object) {
    return request({
        url: `/device/device/getDevicesByParam/${object.pageSize}/${object.pageIndex}`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备列表--提交新增设备表单
export function submitAddFormOfDeviceList (object) {
    return request({
        url: `/device/device/saveDevice`,
        method: 'post',
        data: object,
        params: {
            lpCategory: import.meta.env.VITE_CATEGORY
        },
        type: 'JSON'
    })
}
//  设备列表--提交编辑设备表单
export function submitEditFormOfDeviceList (object) {
    return request({
        url: `/device/device/editDevice`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备列表--获取设备详情
export function getDetailDataOfDeviceList (object) {
    return request({
        url: `/device/device/byId/${object.deviceId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备列表--提交删除设备表单
export function submitDeleteFormOfDeviceList (object) {
    return request({
        url: `/device/jywsRoomDevice/deleteDeviceBatch`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备列表--批量重新生成设备二维码
export function createQrCodeOfDeviceList (object) {
    return request({
        url: `/device/device/rebuildQrCode`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备列表--下载单独设备二维码
export function downloadSingleQrCodeOfDeviceList (object) {
    return download({
        url: `/device/device/getQrCode/${object.deviceId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备列表--下载批量设备二维码
export function downloadBatchQrCodeOfDeviceList (object) {
    return download({
        url: `/device/device/getAllQrCode`,
        method: 'post',
        data: object,
        type: 'JSON'
    })
}
//  设备列表--导出批量更新模板
export function downloadBatchEditMouldOfDeviceList (object) {
    return download({
        url: `/device/device/exportBatchUpdateDevices/${object.projectId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
//  设备列表--导出批量导入模板
export function downloadBatchImportMouldOfDeviceList (object) {
    return download({
        url: `/device/device/exportBatchAddTemplate/${object.projectId}`,
        method: 'get',
        params: object,
        type: 'JSON'
    })
}
